@@ -13,6 +13,7 @@ import apt
 import apt.debfile
 import re
 from mimetypes import guess_type
+from urllib.parse import urlparse
 import aptkit.simpleclient
 import aptkit.enums
 
@@ -416,8 +417,10 @@ class URLApp():
         self.uih = UIHelper(None)
 
         # parse URL
-        url = url.replace("apt://", "")
-        self.pkgname = url.split("?")[0]
+        parsed_url = urlparse(url)
+        self.pkgname = parsed_url.path
+        if not self.pkgname:
+            self.pkgname = parsed_url.netloc
 
         # update the cache
         apt = aptkit.simpleclient.SimpleAPTClient(None)
@@ -492,7 +495,7 @@ if len(sys.argv) != 2:
 
 argument = os.path.expanduser(sys.argv[1])
 
-if "apt://" in argument:
+if argument.lower().startswith("apt:"):
     app = URLApp(argument)
 else:
     if not os.path.exists(argument):
